# dxw

Simple dynamic time, depth, space or whatever warping


## Installation

You can install with `pip`:

    pip install dxw


## Documentation

Coming soon!


## Contributing

Please see [CONTRIBUTING.md](CONTRIBUTING.md).
